==> 0.0.4.tar.gz: lib/kameleoon_exception.dart <==
// Exception indicating that the the visitor code is empty or longer than 255 chars
class VisitorCodeNotValid implements Exception {
  late String _message;

  VisitorCodeNotValid(
      [String? message = 'Visitor code is empty or longer than 255 chars']) {
    this._message = message!;
  }

  @override
  String toString() {
    return _message;
  }
}


// Exception indicating that the request experiment ID has not been found in the internal configuration of the SDK. This is usually normal and means that the experiment has not yet been started on Kameleoon's side (but code triggering / implementing variations is already deployed on the mobile app's side).
class ExperimentConfigurationNotFound implements Exception {
  late String _message;

  ExperimentConfigurationNotFound(
      [String message = 'Experiment configuration not found']) {
    this._message = message;
  }

  @override
  String toString() {
    return _message;
  }
}

// Exception indicating that the requested feature ID has not been found in the internal configuration of the SDK. This is usually normal and means that the feature flag has not yet been activated on Kameleoon's side (but code implementing the feature is already deployed on the web-application's side).
class FeatureConfigurationNotFound implements Exception {
  late String _message;

  FeatureConfigurationNotFound(
      [String message = 'Feature configuration not found']) {
    this._message = message;
  }

  @override
  String toString() {
    return _message;
  }
}

// Exception indicating that the requested variation ID has not been found in the internal configuration of the SDK. This is usually normal and means that the variation's corresponding experiment has not yet been activated on Kameleoon's side.
class VariationConfigurationNotFound implements Exception {
  late String _message;

  VariationConfigurationNotFound(
      [String message = 'Variation configuration not found']) {
    this._message = message;
  }

  @override
  String toString() {
    return _message;
  }
}

// Exception indicating that the current user did not trigger the required targeting conditions for this experiment. The targeting conditions are defined via Kameleoon's segment builder.
class NotTargeted implements Exception {
  late String _message;

  NotTargeted([String message = 'Not targeted']) {
    this._message = message;
  }

  @override
  String toString() {
    return _message;
  }
}

// Exception indicating that the current user triggered the experiment (met the targeting conditions), but did not activate it. The most common reason for that is that part of the traffic has been excluded from the experiment and should not be tracked.
class NotActivated implements Exception {
  late String _message;

  NotActivated([String message = 'Not activated']) {
    this._message = message;
  }

  @override
  String toString() {
    return _message;
  }
}

// Exception indicating that the SDK has not completed its initialization yet.
class SDKNotReady implements Exception {
  late String _message;

  SDKNotReady([String message = 'SDK not ready']) {
    this._message = message;
  }

  @override
  String toString() {
    return _message;
  }
}

==> 0.0.9.tar.gz: lib/kameleoon_exception.dart <==
// Exception indicating that the the visitor code is empty or longer than 255 chars
class VisitorCodeNotValid implements Exception {
  late String _message;

  VisitorCodeNotValid(
      [String? message = 'Visitor code is empty or longer than 255 chars']) {
    this._message = message!;
  }

  @override
  String toString() {
    return _message;
  }
}


// Exception indicating that the request experiment ID has not been found in the internal configuration of the SDK. This is usually normal and means that the experiment has not yet been started on Kameleoon's side (but code triggering / implementing variations is already deployed on the mobile app's side).
class ExperimentConfigurationNotFound implements Exception {
  late String _message;

  ExperimentConfigurationNotFound(
      [String? message = 'Experiment configuration not found']) {
    this._message = message!;
  }

  @override
  String toString() {
    return _message;
  }
}

// Exception indicating that the requested feature ID has not been found in the internal configuration of the SDK. This is usually normal and means that the feature flag has not yet been activated on Kameleoon's side (but code implementing the feature is already deployed on the web-application's side).
class FeatureConfigurationNotFound implements Exception {
  late String _message;

  FeatureConfigurationNotFound(
      [String? message = 'Feature configuration not found']) {
    this._message = message!;
  }

  @override
  String toString() {
    return _message;
  }
}

// Exception indicating that the requested variation ID has not been found in the internal configuration of the SDK. This is usually normal and means that the variation's corresponding experiment has not yet been activated on Kameleoon's side.
class VariationConfigurationNotFound implements Exception {
  late String _message;

  VariationConfigurationNotFound(
      [String? message = 'Variation configuration not found']) {
    this._message = message!;
  }

  @override
  String toString() {
    return _message;
  }
}

// Exception indicating that the current user did not trigger the required targeting conditions for this experiment. The targeting conditions are defined via Kameleoon's segment builder.
class NotTargeted implements Exception {
  late String _message;

  NotTargeted([String? message = 'Not targeted']) {
    this._message = message!;
  }

  @override
  String toString() {
    return _message;
  }
}

// Exception indicating that the current user triggered the experiment (met the targeting conditions), but did not activate it. The most common reason for that is that part of the traffic has been excluded from the experiment and should not be tracked.
class NotActivated implements Exception {
  late String _message;

  NotActivated([String? message = 'Not activated']) {
    this._message = message!;
  }

  @override
  String toString() {
    return _message;
  }
}

// Exception indicating that the SDK has not completed its initialization yet.
class SDKNotReady implements Exception {
  late String _message;

  SDKNotReady([String? message = 'SDK not ready']) {
    this._message = message!;
  }

  @override
  String toString() {
    return _message;
  }
}
